/*
	  '
*/

#include <fstream>
#include <algorithm>
#include <cstdlib>
#include <cstring>

using namespace std;

const int MAXN = 40;
const int MAXL = (1 << ((MAXN-1)/2)) + 4;

template<class T> struct StaticArray
{
	int N;
	T data[MAXL];
	StaticArray<T> (void) : N(0) { } ;
	inline void assign_with(const StaticArray<T> &that)
	{
		this->N = that.N;
		memcpy(this->data, that.data, that.N*sizeof(T));
	}
};

typedef long long ll;

struct segm
{
	ll tfree, tpaid;
	ll pay;
} data[MAXN];

ll tchange[MAXN];
ll MAX_T, MAX_P;

const ll INFTY = 132011201120112011LL;

ifstream fin("highway.dat");
ofstream fout("highway.sol");

struct opt_pair
{
	ll t;
	ll p;
	opt_pair(void) : t(INFTY), p(INFTY) { } ;
	opt_pair(ll t_, ll p_) : t(t_), p(p_) { } ;
};

StaticArray<opt_pair> left_free, left_paid, right_free, right_paid;

struct both_seqs
{
	StaticArray<opt_pair> ends_free, ends_paid;
};

#define PUSH_IF_NEED(curr) if(result.N==0 || result.data[result.N-1].t > curr.t)result.data[result.N++] = curr;
#define MK_CURR_IN_FREE opt_pair(prev_free.data[i].t + t_add_if_prev_free + t_add_just_now, prev_free.data[i].p + p_add_just_now)
#define MK_CURR_IN_PAID opt_pair(prev_paid.data[j].t + t_add_if_prev_paid + t_add_just_now, prev_paid.data[j].p + p_add_just_now)

void spec_merge(const StaticArray<opt_pair> &prev_free, 
				const StaticArray<opt_pair> &prev_paid,
				StaticArray<opt_pair> &result, 
				ll t_add_if_prev_free, ll t_add_if_prev_paid,
				ll t_add_just_now, ll p_add_just_now)
{
	result.N = 0;
	int i=0, j=0;
	opt_pair curr_in_free = MK_CURR_IN_FREE;
	opt_pair curr_in_paid = MK_CURR_IN_PAID;
	while(i<prev_free.N && j<prev_paid.N)
	{
		if(curr_in_free.p < curr_in_paid.p  ||  curr_in_free.p==curr_in_paid.p && curr_in_free.t < curr_in_paid.t)
		{
			PUSH_IF_NEED(curr_in_free) // push_if_need(result, curr_in_free);
			++i; //      ,     .
				//         ,    ,
				//        ',     
			curr_in_free = MK_CURR_IN_FREE;
		}
		else
		{
			PUSH_IF_NEED(curr_in_paid) // push_if_need(result, curr_in_paid);
			++j; // . 
			curr_in_paid = MK_CURR_IN_PAID;
		}
	}
	while(i<prev_free.N)
	{
		PUSH_IF_NEED(curr_in_free) // push_if_need(result, curr_in_free);
		++i; // . 
		curr_in_free = MK_CURR_IN_FREE;
	}
	while(j<prev_paid.N)
	{
		PUSH_IF_NEED(curr_in_paid) // push_if_need(result, curr_in_paid);
		++j; // . 
		curr_in_paid = MK_CURR_IN_PAID;
	}

//#ifdef _DEBUG
//	fprintf(stderr, "\nspec_merge result : %d ", result.N);
//	for(int i=0; i<result.N; i++)
//		fprintf(stderr, " (%lld,%lld)", result.data[i].t, result.data[i].p);
//#endif
}

void GenOne(segm data[], int N_, ll tchange[],
			StaticArray<opt_pair> &free, StaticArray<opt_pair> &paid)
{
	static both_seqs result[2];
	result[0].ends_free.N = 0;
	result[0].ends_free.data[result[0].ends_free.N++] = opt_pair(data[0].tfree, 0);
	result[0].ends_paid.N = 0;
	result[0].ends_paid.data[result[0].ends_paid.N++] = opt_pair(data[0].tpaid, data[0].pay);
	for(int i=1; i<N_; i++)
	{
		spec_merge(result[(i-1)%2].ends_free, result[(i-1)%2].ends_paid, result[i%2].ends_free, 0LL, tchange[i-1], data[i].tfree, 0LL);
		spec_merge(result[(i-1)%2].ends_free, result[(i-1)%2].ends_paid, result[i%2].ends_paid, tchange[i-1], 0LL, data[i].tpaid, data[i].pay);
	}
	free.assign_with(result[(N_-1)%2].ends_free);
	paid.assign_with(result[(N_-1)%2].ends_paid);
}

int N, N_1, N_2;
ll build_ans_2_one(const StaticArray<opt_pair> &left, const StaticArray<opt_pair> &right, ll max_t)
{
	ll result = INFTY;
	int j = right.N-1;
	for(int i = 0; i < left.N; i++)
	{
		while(j > 0  &&  left.data[i].t + right.data[j-1].t <= max_t)
			j--;
		if(left.data[i].t + right.data[j].t <= max_t)
			result = min(result, left.data[i].p + right.data[j].p);
	}
	return result;	
}

ll build_ans_2(ll MAX_T)
{
	ll ans = INFTY;	
	ans = min(ans, build_ans_2_one(left_free, right_free, MAX_T));
	ans = min(ans, build_ans_2_one(left_paid, right_paid, MAX_T));
	ans = min(ans, build_ans_2_one(left_free, right_paid, MAX_T - tchange[N_1-1]));
	ans = min(ans, build_ans_2_one(left_paid, right_free, MAX_T - tchange[N_1-1]));
	if(ans==INFTY)
		ans = -1LL;
	return ans;
}

ll build_ans_3_one(const StaticArray<opt_pair> &left, const StaticArray<opt_pair> &right, ll max_p)
{
	ll result = INFTY;
	int j = 0;
	for(int i = left.N-1; i>=0; i--)
	{
		while(j+1 < right.N  &&  left.data[i].p + right.data[j+1].p <= max_p)
			j++;
		if(left.data[i].p + right.data[j].p <= max_p)
			result = min(result, left.data[i].t + right.data[j].t);
	}
	return result;	
}

ll build_ans_3(ll MAX_P)
{
	ll ans = INFTY;	
	ans = min(ans, build_ans_3_one(left_free, right_free, MAX_P));
	ans = min(ans, build_ans_3_one(left_paid, right_paid, MAX_P));
	ans = min(ans, build_ans_3_one(left_free, right_paid, MAX_P) + tchange[N_1-1]);
	ans = min(ans, build_ans_3_one(left_paid, right_free, MAX_P) + tchange[N_1-1]);
	if(ans==INFTY)
		ans = -1LL;
	return ans;
}

void GenBoth(void)
{
	N_1 = N/2;
	N_2 = N - N_1;
	GenOne(data, N_1, tchange, left_free, left_paid);
	reverse(data, data+N);
	reverse(tchange, tchange+N-1);
	GenOne(data, N_2, tchange, right_free, right_paid);
	reverse(tchange, tchange+N-1);
//	reverse(data, data+N);
}

void ReadData(void)
{
	fin >> N >> MAX_T >> MAX_P;
	fin >> data[0].tfree >> data[0].tpaid >> data[0].pay;
	for(int i=1; i<N; i++)
		fin >> tchange[i-1] >> data[i].tfree >> data[i].tpaid >> data[i].pay;
}

int main(int argc, char* argv[])
{
	ReadData();
	GenBoth();
	ll res_2 = build_ans_2(MAX_T);
	ll res_3 = build_ans_3(MAX_P);
	fout << res_2 << " " << res_3 << endl;
	return 0;
}
